package com.huiju.estateagents.service.impl;

import com.huiju.estateagents.base.ResponseBean;
import com.huiju.estateagents.common.CommConstant;
import com.huiju.estateagents.exception.EstaException;
import com.huiju.estateagents.mapper.TaPersonMapper;
import com.huiju.estateagents.po.PersonPO;
import com.huiju.estateagents.service.IStatisticalService;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.time.LocalDateTime;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * 数据统计
 */
@Service
@Slf4j
public class StatisticalServiceImpl implements IStatisticalService {

    @Autowired
    private TaPersonMapper taPersonMapper;


    @Override
    public ResponseBean indexStatistical() {

        ResponseBean responseBean = new ResponseBean();
        Map<String,Object> map = new HashMap<>();

        // 总用户数
        Integer selectUserCount = taPersonMapper.selectUserCount(CommConstant.PERSON_REALTY_CONSULTANT);

        // 注册数
        Integer selectRegisteredCount = taPersonMapper.selectRegisteredCount(CommConstant.PERSON_REALTY_CONSULTANT);

        // 最近七天
        Integer selectRecentlyCount = taPersonMapper.selectRecentlyCount(CommConstant.PERSON_REALTY_CONSULTANT, null, null);

        // 用户行为
        List<PersonPO> selectUserBehavior = taPersonMapper.selectUserBehavior(CommConstant.PERSON_REALTY_CONSULTANT, null, null);

        // 用户活跃数 / 新增用户数
        List<Map<String, Object>> selectActiveUserCount = taPersonMapper.selectActiveUserCount(CommConstant.PERSON_REALTY_CONSULTANT, CommConstant.DAY, null, null);

        // 性别比例
        List<Map<String, Object>> selectSexUser = taPersonMapper.selectSexUser(CommConstant.PERSON_REALTY_CONSULTANT);

        map.put("selectUserCount", selectUserCount);
        map.put("selectRegisteredCount", selectRegisteredCount);
        map.put("selectRecentlyCount", selectRecentlyCount);
        map.put("selectUserBehavior", selectUserBehavior);
        map.put("selectActiveUserCount", selectActiveUserCount);
        map.put("selectSexUser", selectSexUser);

        responseBean.addSuccess(map);

        return responseBean;
    }

    @Override
    public ResponseBean selectActiveUserCount(String dateType) {
        ResponseBean responseBean = new ResponseBean();

        String type = null;
        if (CommConstant.DAY.equals(dateType)) {
            type = CommConstant.DAY;
        } else if (CommConstant.WEEK.equals(dateType)) {
            type = CommConstant.WEEK;
        } else if (CommConstant.MONTH.equals(dateType)) {
            type = CommConstant.MONTH;
        } else {
            responseBean.addError("无此查询类型！");
        }

        // 用户活跃数
        List<Map<String, Object>> selectActiveUserCount = taPersonMapper.selectActiveUserCount(CommConstant.PERSON_REALTY_CONSULTANT, type, null, null);
        Map<String, Object> map = new HashMap<>();
        map.put("selectActiveUserCount", selectActiveUserCount);
        responseBean.addSuccess(map);
        return responseBean;
    }
}
